<?xml version="1.0" ?><!DOCTYPE TS><TS language="en_AU" version="2.1">
<context>
    <name>CDayMonthView</name>
    <message>
        <source>Monday</source>
        <translation>Monday</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Tuesday</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Wednesday</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Thursday</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Friday</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Saturday</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Sunday</translation>
    </message>
</context>
<context>
    <name>CDayWindow</name>
    <message>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
</context>
<context>
    <name>CGraphicsView</name>
    <message>
        <source>New Event</source>
        <translation>New Event</translation>
    </message>
</context>
<context>
    <name>CMonthGraphiview</name>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>You are deleting an event.</source>
        <translation>You are deleting an event.</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation>Are you sure you want to delete this event?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>Do you want to delete all occurrences of this event, or only the selected occurrence?</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Delete All</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation>Delete Only This Event</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation>Delete All Future Events</translation>
    </message>
</context>
<context>
    <name>CMonthSchceduleNumButton</name>
    <message>
        <source>%1 more</source>
        <translation>%1 more</translation>
    </message>
</context>
<context>
    <name>CMonthView</name>
    <message>
        <source>New event</source>
        <translation>New event</translation>
    </message>
    <message>
        <source>New Event</source>
        <translation>New Event</translation>
    </message>
</context>
<context>
    <name>CMonthWindow</name>
    <message>
        <source>Y</source>
        <translation>Y</translation>
    </message>
</context>
<context>
    <name>CMySchceduleView</name>
    <message>
        <source>You are deleting an event.</source>
        <translation>You are deleting an event.</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation>Are you sure you want to delete this event?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>Do you want to delete all occurrences of this event, or only the selected occurrence?</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Delete All</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation>Delete Only This Event</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</translation>
    </message>
    <message>
        <source>My Event</source>
        <translation>My Event</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Edit</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation>Delete All Future Events</translation>
    </message>
</context>
<context>
    <name>CSchceduleDlg</name>
    <message>
        <source>New Event</source>
        <translation>New Event</translation>
    </message>
    <message>
        <source>Edit Event</source>
        <translation>Edit Event</translation>
    </message>
    <message>
        <source>All occurrences of a repeating event must have the same all-day status.</source>
        <translation>All occurrences of a repeating event must have the same all-day status.</translation>
    </message>
    <message>
        <source>Do you want to change all occurrences?</source>
        <translation>Do you want to change all occurrences?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <source>Change All</source>
        <translation>Change All</translation>
    </message>
    <message>
        <source>You are changing the repeating rule of this event.</source>
        <translation>You are changing the repeating rule of this event.</translation>
    </message>
    <message>
        <source>You are changing a repeating event.</source>
        <translation>You are changing a repeating event.</translation>
    </message>
    <message>
        <source>Do you want to change only this occurrence of the event, or all occurrences?</source>
        <translation>Do you want to change only this occurrence of the event, or all occurrences?</translation>
    </message>
    <message>
        <source>All</source>
        <translation>All</translation>
    </message>
    <message>
        <source>Only This Event</source>
        <translation>Only This Event</translation>
    </message>
    <message>
        <source>Do you want to change only this occurrence of the event, or this and all future occurrences?</source>
        <translation>Do you want to change only this occurrence of the event, or this and all future occurrences?</translation>
    </message>
    <message>
        <source>All Future Events</source>
        <translation>All Future Events</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Never</translation>
    </message>
    <message>
        <source>At time of event</source>
        <translation>At time of event</translation>
    </message>
    <message>
        <source>15 minutes before</source>
        <translation>15 minutes before</translation>
    </message>
    <message>
        <source>30 minutes before</source>
        <translation>30 minutes before</translation>
    </message>
    <message>
        <source>1 hour before</source>
        <translation>1 hour before</translation>
    </message>
    <message>
        <source>1 day before</source>
        <translation>1 day before</translation>
    </message>
    <message>
        <source>2 days before</source>
        <translation>2 days before</translation>
    </message>
    <message>
        <source>1 week before</source>
        <translation>1 week before</translation>
    </message>
    <message>
        <source>On start day (9:00 AM)</source>
        <translation>On start day (9:00 AM)</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Type:</translation>
    </message>
    <message>
        <source>All Day:</source>
        <translation>All Day:</translation>
    </message>
    <message>
        <source>Remind Me:</source>
        <translation>Remind Me:</translation>
    </message>
    <message>
        <source>Repeat:</source>
        <translation>Repeat:</translation>
    </message>
    <message>
        <source>Daily</source>
        <translation>Daily</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Weekdays</translation>
    </message>
    <message>
        <source>Weekly</source>
        <translation>Weekly</translation>
    </message>
    <message>
        <source>Monthly</source>
        <translation>Monthly</translation>
    </message>
    <message>
        <source>Yearly</source>
        <translation>Yearly</translation>
    </message>
    <message>
        <source>End Repeat:</source>
        <translation>End Repeat:</translation>
    </message>
    <message>
        <source>After</source>
        <translation>After</translation>
    </message>
    <message>
        <source>On</source>
        <translation>On</translation>
    </message>
    <message>
        <source>time(s)</source>
        <translation>time(s)</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Save</translation>
    </message>
    <message>
        <source>New event</source>
        <translation>New event</translation>
    </message>
    <message>
        <source>End time must be greater than start time</source>
        <translation>End time must be greater than start time</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <source>All Day</source>
        <translation>All Day</translation>
    </message>
    <message>
        <source>Starts</source>
        <translation>Starts</translation>
    </message>
    <message>
        <source>Ends</source>
        <translation>Ends</translation>
    </message>
    <message>
        <source>Remind Me</source>
        <translation>Remind Me</translation>
    </message>
    <message>
        <source>Repeat</source>
        <translation>Repeat</translation>
    </message>
    <message>
        <source>End Repeat</source>
        <translation>End Repeat</translation>
    </message>
    <message>
        <source>Ends:</source>
        <translation>Ends:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Description:</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <source>Starts:</source>
        <translation>Starts:</translation>
    </message>
    <message>
        <source>Work</source>
        <translation>Work</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Life</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Other</translation>
    </message>
</context>
<context>
    <name>CSchceduleSearchDateItem</name>
    <message>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
</context>
<context>
    <name>CSchceduleSearchItem</name>
    <message>
        <source>Edit</source>
        <translation>Edit</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>You are deleting an event.</source>
        <translation>You are deleting an event.</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation>Are you sure you want to delete this event?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>Do you want to delete all occurrences of this event, or only the selected occurrence?</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Delete All</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation>Delete Only This Event</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation>Delete All Future Events</translation>
    </message>
    <message>
        <source>All Day</source>
        <translation>All Day</translation>
    </message>
</context>
<context>
    <name>CSchceduleSearchView</name>
    <message>
        <source>No search results</source>
        <translation>No search results</translation>
    </message>
</context>
<context>
    <name>CScheduleView</name>
    <message>
        <source>ALL DAY</source>
        <translation>ALL DAY</translation>
    </message>
</context>
<context>
    <name>CWeekWindow</name>
    <message>
        <source>Week</source>
        <translation>Week</translation>
    </message>
    <message>
        <source>Y</source>
        <translation>Y</translation>
    </message>
</context>
<context>
    <name>CYearSchceduleItem</name>
    <message>
        <source>All Day</source>
        <translation>All Day</translation>
    </message>
</context>
<context>
    <name>CYearSchceduleView</name>
    <message>
        <source>All Day</source>
        <translation>All Day</translation>
    </message>
    <message>
        <source>No event</source>
        <translation>No event</translation>
    </message>
</context>
<context>
    <name>CYearWindow</name>
    <message>
        <source>Y</source>
        <translation>Y</translation>
    </message>
</context>
<context>
    <name>CalendarWindow</name>
    <message>
        <source>Calendar</source>
        <translation>Calendar</translation>
    </message>
    <message>
        <source>Calendar is a tool to view dates, and also a smart daily planner to schedule all things in life. </source>
        <translation>Calendar is a tool to view dates, and also a smart daily planner to schedule all things in life. </translation>
    </message>
</context>
<context>
    <name>Calendarmainwindow</name>
    <message>
        <source>Calendar</source>
        <translation>Calendar</translation>
    </message>
    <message>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
</context>
<context>
    <name>CenterWidget</name>
    <message>
        <source>All Day</source>
        <translation>All Day</translation>
    </message>
</context>
<context>
    <name>DragInfoGraphicsView</name>
    <message>
        <source>Edit</source>
        <translation>Edit</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>New event</source>
        <translation>New event</translation>
    </message>
    <message>
        <source>You are deleting an event.</source>
        <translation>You are deleting an event.</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation>Are you sure you want to delete this event?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>Do you want to delete all occurrences of this event, or only the selected occurrence?</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Delete All</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation>Delete Only This Event</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation>Delete All Future Events</translation>
    </message>
    <message>
        <source>New Event</source>
        <translation>New Event</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <source>Today</source>
        <comment>Return</comment>
        <translation>Today</translation>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation>Today</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <source>Delete event</source>
        <translation>Delete event</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copy</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Cut</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Paste</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>Select all</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
</context>
<context>
    <name>YearFrame</name>
    <message>
        <source>Y</source>
        <translation>Y</translation>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <source>Today</source>
        <comment>Today</comment>
        <translation>Today</translation>
    </message>
</context>
</TS>